@@ -760,7 +760,8 @@ static PyObject *_PylibMC_Pickle(PyObject *val) {
     retval = NULL;
     pickle_dump = _PylibMC_GetPickles("dumps");
     if (pickle_dump != NULL) {
-        retval = PyObject_CallFunctionObjArgs(pickle_dump, val, NULL);
+        retval = PyObject_CallFunctionObjArgs(pickle_dump, val,
+                                              PyInt_FromLong(-1), NULL);
         Py_DECREF(pickle_dump);
     }
 
