@@ -83,6 +83,16 @@ TypeError: key must be an instance of str
 Traceback (most recent call last):
   ...
 TypeError: key must be an instance of str
+
+Also test some flush all.
+>>> c.set("hi", "guys")
+True
+>>> c.get("hi")
+'guys'
+>>> c.flush_all()
+True
+>>> c.get("hi")
+>>>
 """
 
 import _pylibmc
